Class: LiveCable::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/live_cable/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Returns a new instance of Configuration.



15
16
17
# File 'lib/live_cable/configuration.rb', line 15

def initialize
  @verbose_errors = !Rails.env.production?
end

Instance Attribute Details

#verbose_errorsObject

When true, error broadcasts include the full backtrace. Defaults to true outside of production so developers see stack traces, and false in production to avoid leaking internals to the client. Override in an initializer:

LiveCable.configure do |config|
config.verbose_errors = false
end


13
14
15
# File 'lib/live_cable/configuration.rb', line 13

def verbose_errors
  @verbose_errors
end