Module: LiveCable::Delegation
- Defined in:
- lib/live_cable/delegator.rb,
lib/live_cable/delegation/hash.rb,
lib/live_cable/delegation/array.rb,
lib/live_cable/delegation/model.rb,
lib/live_cable/delegation/methods.rb
Overview
Delegation modules for different data types. Each module defines which methods should trigger change notifications.
Defined Under Namespace
Modules: Array, Hash, Methods, Model
Constant Summary collapse
- SUPPORTED =
Maps Ruby classes to their delegation modules. When a value of one of these types is stored in a container, it will be wrapped in a Delegator and extended with the appropriate module.
{ ::ActiveRecord::Base => Delegation::Model, ::Array => Delegation::Array, ::Hash => Delegation::Hash, }.freeze